@@ -1,13 +1,13 @@
 package Log::Any::Manager;
 BEGIN {
-  $Log::Any::Manager::VERSION = '0.05';
+  $Log::Any::Manager::VERSION = '0.06';
 }
 use strict;
 use warnings;
 use Carp qw(croak);
 use Devel::GlobalDestruction;
 use Log::Any::Adapter::Util qw(require_dynamic);
-use Scope::Guard;
+use Guard;
 
 sub new {
     my $class = shift;
@@ -100,8 +100,8 @@ sub set {
     $self->_reselect_matching_adapters($pattern);
 
     if ( my $lex_ref = $options->{lexically} ) {
-        $$lex_ref = Scope::Guard->new(
-            sub { $self->remove($entry) if !in_global_destruction } );
+        $$lex_ref =
+          Guard::guard { $self->remove($entry) if !in_global_destruction };
     }
 
     return $entry;
